@@ -3,51 +3,37 @@ package Siffra::Tools;
 use 5.014;
 use strict;
 use warnings;
+use Carp;
+$Carp::Verbose = 1;
 use utf8;
-use DDP;
 use Data::Dumper;
-use Data::Dumper::AutoEncode;
+use DDP;
 use Log::Any qw($log);
 use Scalar::Util qw(blessed);
 
-use Carp;
-$Carp::Verbose = 1;
+$| = 1;    #autoflush
+
+use constant {
+    FALSE => 0,
+    TRUE  => 1,
+    DEBUG => $ENV{ DEBUG } // 0,
+};
 
 BEGIN
 {
+    binmode( STDOUT, ":encoding(UTF-8)" );
+    binmode( STDERR, ":encoding(UTF-8)" );
+
+    require Siffra::Base;
     use Exporter ();
     use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-    $VERSION = '0.03';
-    @ISA     = qw(Exporter);
+    $VERSION = '0.04';
+    @ISA     = qw(Siffra::Base Exporter);
 
     #Give a hoot don't pollute, do not export more than needed by default
     @EXPORT      = qw();
     @EXPORT_OK   = qw();
     %EXPORT_TAGS = ();
-
-    $SIG{ __DIE__ } = sub {
-        $log->info( 'Entrando em __DIE__', { package => __PACKAGE__ } );
-        if ( $^S )
-        {
-            $log->debug( 'Entrando em __DIE__ eval {}', { package => __PACKAGE__ } );
-
-            # We're in an eval {} and don't want log
-            # this message but catch it later
-            return;
-        } ## end if ( $^S )
-
-        ( my $message = $_[ 0 ] ) =~ s/\n|\r//g;
-        $log->fatal( $message, { package => __PACKAGE__ } );
-
-        die eDumper @_;    # Now terminate really
-    };
-
-    $SIG{ __WARN__ } = sub {
-        p @_;
-        state $count = 0;
-        ( my $message = $_[ 0 ] ) =~ s/\n|\r//g;
-        $log->warn( $message, { package => __PACKAGE__, count => $count++, global_phase => ${^GLOBAL_PHASE} } );
-    };
 } ## end BEGIN
 
 #################### subroutine header begin ####################
@@ -69,7 +55,7 @@ See Also   :
 #################### subroutine header end ####################
 
 =head2 C<new()>
- 
+
   Usage     : $self->block_new_method() within text_pm_file()
   Purpose   : Build 'new()' method as part of a pm file
   Returns   : String holding sub new.
@@ -80,7 +66,7 @@ See Also   :
   Comment   : This method is a likely candidate for alteration in a subclass,
               e.g., pass a single hash-ref to new() instead of a list of
               parameters.
- 
+
 =cut
 
 sub new
@@ -91,7 +77,7 @@ sub new
 
     $self = bless( $self, ref( $class ) || $class );
 
-    $log->info( "new", { progname => $0, pid => $$, perl_version => $], package => __PACKAGE__ } );
+    $log->debug( "new", { progname => $0, pid => $$, perl_version => $], package => __PACKAGE__ } );
 
     return $self;
 } ## end sub new
@@ -99,7 +85,7 @@ sub new
 sub _initialize()
 {
     my ( $self, %parameters ) = @_;
-    $log->info( "_initialize", { package => __PACKAGE__ } );
+    $log->debug( "_initialize", { package => __PACKAGE__ } );
 
     require JSON::XS;
     $self->{ json } = JSON::XS->new->utf8;
@@ -107,43 +93,19 @@ sub _initialize()
 
 sub END
 {
-    $log->info( "END", { package => __PACKAGE__ } );
+    $log->debug( "END", { package => __PACKAGE__ } );
+    eval { $log->{ adapter }->{ dispatcher }->{ outputs }->{ Email }->flush; };
 }
 
-=head2 C<AUTOLOAD>
- 
-  Usage     : $self->block_new_method() within text_pm_file()
-  Purpose   : Build 'new()' method as part of a pm file
-  Returns   : String holding sub new.
-  Argument  : $module: pointer to the module being built
-              (as there can be more than one module built by EU::MM);
-              for the primary module it is a pointer to $self
-  Throws    : n/a
-  Comment   : This method is a likely candidate for alteration in a subclass,
-              e.g., pass a single hash-ref to new() instead of a list of
-              parameters.
- 
-=cut
-
-sub AUTOLOAD
-{
-    my ( $self, @parameters ) = @_;
-    our $AUTOLOAD;
-
-    return if ( $AUTOLOAD =~ /DESTROY/ );
-
-    #carp( qq(Não existe a sub "$AUTOLOAD"...) );
-} ## end sub AUTOLOAD
-
 sub DESTROY
 {
     my ( $self, %parameters ) = @_;
-    $log->info( 'DESTROY', { package => __PACKAGE__, GLOBAL_PHASE => ${^GLOBAL_PHASE} } );
+    $log->debug( 'DESTROY', { package => __PACKAGE__, GLOBAL_PHASE => ${^GLOBAL_PHASE} } );
     return if ${^GLOBAL_PHASE} eq 'DESTRUCT';
 
     if ( blessed( $self ) && $self->isa( __PACKAGE__ ) )
     {
-        $log->alert( "DESTROY", { package => __PACKAGE__, GLOBAL_PHASE => ${^GLOBAL_PHASE}, blessed => 1 } );
+        $log->debug( "DESTROY", { package => __PACKAGE__, GLOBAL_PHASE => ${^GLOBAL_PHASE}, blessed => 1 } );
     }
     else
     {
@@ -152,7 +114,7 @@ sub DESTROY
 } ## end sub DESTROY
 
 =head2 C<getFileMD5()>
- 
+
   Usage     : $self->block_new_method() within text_pm_file()
   Purpose   : Build 'new()' method as part of a pm file
   Returns   : String holding sub new.
@@ -163,7 +125,7 @@ sub DESTROY
   Comment   : This method is a likely candidate for alteration in a subclass,
               e.g., pass a single hash-ref to new() instead of a list of
               parameters.
- 
+
 =cut
 
 #-------------------------------------------------------------------------------
@@ -245,7 +207,7 @@ LICENSE file included with this module.
 =head1 SEE ALSO
 
 perl(1).
- 
+
 =cut
 
 #################### main pod documentation end ###################
